class BaseApiModule:
    """
    A base class for all API modules.
    Gives access to the client and provides
    a common interface for all modules.
    """

    def __init__(self, client):
        self.client = client
