"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class LocationLayerProfilesApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        Returns an array of LocationLayerProfile.

        :param dict params: limit: integer
        offset: integer
        ordering: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/LocationLayerProfile'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_location-layer-profiles_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/location-layer-profiles/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        View LocationLayerProfile


        :param dict json: $ref: '#/components/requestBodies/LocationLayerProfile'

        :returns: $ref: '#/components/schemas/LocationLayerProfile'

        https://docs.huvrdata.app/reference/api_location-layer-profiles_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/location-layer-profiles/",
            json=json,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific LocationLayerProfile
        :params id

        :returns: $ref: '#/components/schemas/LocationLayerProfile'

        https://docs.huvrdata.app/reference/api_location-layer-profiles_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/location-layer-profiles/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        View LocationLayerProfile


        :param dict json: $ref: '#/components/requestBodies/LocationLayerProfile'

        :returns: $ref: '#/components/schemas/LocationLayerProfile'

        https://docs.huvrdata.app/reference/api_location-layer-profiles_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/location-layer-profiles/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        View LocationLayerProfile


        :param dict json: $ref: '#/components/requestBodies/LocationLayerProfile'

        :returns: $ref: '#/components/schemas/LocationLayerProfile'

        https://docs.huvrdata.app/reference/api_location-layer-profiles_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/location-layer-profiles/{id}/",
            json=json,
            **kwargs,
        )

    def delete(self, id, **kwargs):
        """
        View LocationLayerProfile

        https://docs.huvrdata.app/reference/api_location-layer-profiles_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/location-layer-profiles/{id}/",
            **kwargs,
        )
