"""
This file is automatically generated. Do not modify it manually.
"""

from .base_api_module import BaseApiModule


class RecommendedWorkPlansApiModule(BaseApiModule):
    def list(self, params=None, **kwargs):
        """
        return an array of RecommendedWorkPlan

        :param dict params: assessment_revision__assessment__asset: string
        assessment_revision__assessment__asset__asset_path_cache__path: string
        asset__descendants: string
        asset__type__in: string
        description__icontains: string
        due: string
        limit: integer
        name: string
        name__icontains: string
        offset: integer
        ordering: string
        risk_score__display: string
        risk_score__level: string
        status__in: string

        :returns: properties:
          count:
            type: integer
          next:
            format: uri
            nullable: true
            type: string
          previous:
            format: uri
            nullable: true
            type: string
          results:
            items:
              $ref: '#/components/schemas/RecommendedWorkPlanDetail'
            type: array
        required:
        - count
        - results
        type: object

        https://docs.huvrdata.app/reference/api_recommended-work-plans_list
        """
        return self.client.request_json(
            method="get",
            path=f"/api/recommended-work-plans/",
            params=params,
            **kwargs,
        )

    def create(self, json=None, **kwargs):
        """
        View RecommendedWorkPlan
        * Requires authentication

        :param dict json: $ref: '#/components/requestBodies/RecommendedWorkPlanDetail'

        :returns: $ref: '#/components/schemas/RecommendedWorkPlanDetail'

        https://docs.huvrdata.app/reference/api_recommended-work-plans_create
        """
        return self.client.request_json(
            method="post",
            path=f"/api/recommended-work-plans/",
            json=json,
            **kwargs,
        )

    def bulk_edit(self, json=None, **kwargs):
        """
        View RecommendedWorkPlan
        * Requires authentication

        :param dict json: $ref: '#/components/requestBodies/RecommendedWorkPlanDetail'

        :returns: $ref: '#/components/schemas/RecommendedWorkPlanDetail'

        https://docs.huvrdata.app/reference/api_recommended-work-plans_bulk_edit
        """
        return self.client.request_json(
            method="post",
            path=f"/api/recommended-work-plans/bulk-edit/",
            json=json,
            **kwargs,
        )

    def read(self, id, **kwargs):
        """
        Return the specific RecommendedWorkPlan

        :returns: $ref: '#/components/schemas/RecommendedWorkPlanDetail'

        https://docs.huvrdata.app/reference/api_recommended-work-plans_read
        """
        return self.client.request_json(
            method="get",
            path=f"/api/recommended-work-plans/{id}/",
            **kwargs,
        )

    def update(self, id, json=None, **kwargs):
        """
        View RecommendedWorkPlan
        * Requires authentication

        :param dict json: $ref: '#/components/requestBodies/RecommendedWorkPlanDetail'

        :returns: $ref: '#/components/schemas/RecommendedWorkPlanDetail'

        https://docs.huvrdata.app/reference/api_recommended-work-plans_update
        """
        return self.client.request_json(
            method="put",
            path=f"/api/recommended-work-plans/{id}/",
            json=json,
            **kwargs,
        )

    def partial_update(self, id, json=None, **kwargs):
        """
        View RecommendedWorkPlan
        * Requires authentication

        :param dict json: $ref: '#/components/requestBodies/RecommendedWorkPlanDetail'

        :returns: $ref: '#/components/schemas/RecommendedWorkPlanDetail'

        https://docs.huvrdata.app/reference/api_recommended-work-plans_partial_update
        """
        return self.client.request_json(
            method="patch",
            path=f"/api/recommended-work-plans/{id}/",
            json=json,
            **kwargs,
        )

    def delete(self, id, **kwargs):
        """
        View RecommendedWorkPlan
        * Requires authentication

        https://docs.huvrdata.app/reference/api_recommended-work-plans_delete
        """
        return self.client.request_json(
            method="delete",
            path=f"/api/recommended-work-plans/{id}/",
            **kwargs,
        )
