__title__ = "huvr_client"
__description__ = "Python Client for HUVRdata"
__url__ = "https://www.huvrdata.com"
__author__ = "HUVRdata"
__author_email__ = "api@huvrdata.com"
__license__ = "BSD 2.0"
__copyright__ = "Copyright 2023 HUVRdata LLC"
